@@ -2,14 +2,18 @@ context("Check that NCA calculations are working")
 
 test_that("Extravascular single dose data is computed corectly",{
   
-  exvas_sd_dat <- readr::read_table("data_exvas_sd.txt",skip = 1) # Can move this to data
+  exvas_sd_dat <- readr::read_table(
+    "data_exvas_sd.txt",skip = 1,
+    col_types = list(.default = readr::col_double())) # Can move this to data
   
-  exvas_sd_true_result <- readr::read_csv("results_exvas_sd_true.csv")
+  exvas_sd_true_result <- readr::read_csv("results_exvas_sd_true.csv",
+   col_types=list(readr::col_character(),.default = readr::col_double())
+  )
   
   # transpose the true results
   exvas_sd_true_result <- exvas_sd_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=exvas_sd_dat,
@@ -22,7 +26,7 @@ test_that("Extravascular single dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- exvas_sd_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -48,7 +52,7 @@ test_that("Extravascular single dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- exvas_sd_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -74,7 +78,7 @@ test_that("Extravascular multiple dose data is computed corectly",{
   
   exvas_md_true_result <- exvas_md_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=exvas_md_dat,
@@ -91,7 +95,7 @@ test_that("Extravascular multiple dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- exvas_md_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -121,7 +125,7 @@ test_that("Extravascular multiple dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- exvas_md_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -146,7 +150,7 @@ test_that("IV single dose data is computed corectly",{
   
   iv_sd_true_result <- iv_sd_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=iv_sd_dat,
@@ -164,7 +168,7 @@ test_that("IV single dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_sd_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -198,7 +202,7 @@ test_that("IV single dose data is computed corectly",{
  
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_sd_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -224,7 +228,7 @@ test_that("IV multiple dose data is computed corectly",{
   
   iv_md_true_result <- iv_md_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=iv_md_dat,
@@ -243,7 +247,7 @@ test_that("IV multiple dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_md_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -277,7 +281,7 @@ test_that("IV multiple dose data is computed corectly",{
   
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_md_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -303,7 +307,7 @@ test_that("IV infusion single dose data is computed corectly",{
   
   iv_inf_sd_true_result <- iv_inf_sd_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=iv_inf_sd_dat,
@@ -321,7 +325,7 @@ test_that("IV infusion single dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_inf_sd_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -356,7 +360,7 @@ test_that("IV infusion single dose data is computed corectly",{
   
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_inf_sd_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -382,7 +386,7 @@ test_that("IV infusion multiple dose data is computed corectly",{
   
   iv_inf_md_true_result <- iv_inf_md_true_result %>%
     tidyr::gather(var, val, 2:ncol(.)) %>%
-    tidyr::spread_(names(.)[1], "val")
+    tidyr::spread(names(.)[1], "val")
   
   #### test for linear method 
   out <- ncappc(obsFile=iv_inf_md_dat,
@@ -402,7 +406,7 @@ test_that("IV infusion multiple dose data is computed corectly",{
                 noPlot = T)
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_inf_md_true_result %>% 
     dplyr::filter(var=="Linear_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
@@ -437,7 +441,7 @@ test_that("IV infusion multiple dose data is computed corectly",{
   
   
   calc_vals <- out$ncaOutput %>% tibble::as_tibble() %>% 
-    dplyr::mutate_all(dplyr::funs(as.numeric(as.character(.))))
+    dplyr::mutate_all(~as.numeric(as.character(.)))
   true_vals <- iv_inf_md_true_result %>% 
     dplyr::filter(var=="Linear_log_trapezoidal_WinNonlin") %>% 
     dplyr::rename("ID"=var) %>% dplyr::mutate(ID=1)
